import logging
import json

from django.utils import timezone
from django_unicorn.components import UnicornView

from post.models import Message
from post.mqtt import publish


logger = logging.getLogger(__name__)


class MessageView(UnicornView):
    content = ""
    background_color = "black"
    text_color = "white"
    alarm = False
    rgb_colors = {
        "red": (255, 0, 0),
        "green": (0, 255, 0),
        "blue": (0, 0, 255),
        "yellow": (255, 255, 0),
        "orange": (237, 127, 16),
        "purple": (102, 0, 153),
        "pink": (253, 108, 158),
        "white": (255, 255, 255),
        "black": (0, 0, 0),
        "grey": (128, 128, 128),
        "brown": (88, 41, 0),
        "cyan": (0, 255, 255),
        "magenta": (255, 0, 255),
        "olive": (128, 128, 0),
        "teal": (0, 142, 142),
    }

    def author_messages(self):
        return Message.objects.filter(author=self.request.user).order_by("-send_date")[
            :10
        ]

    def resetForm(self):
        self.content = ""
        self.background_color = "black"
        self.text_color = "white"
        self.alarm = False

    def send_message(self):
        if self.content != "":
            logger.warning(
                "send message: %s, %s, %s, %s",
                self.content,
                self.background_color,
                self.text_color,
                self.alarm,
            )
            payload = {
                "text": self.content,
                "background_colour": self.background_color,
                "message_colour": self.text_color,
                "alarm": self.alarm,
            }
            publish("unicorn/messages", json.dumps(payload))
            Message.objects.create(
                content=self.content, author=self.request.user, send_date=timezone.now()
            )
            self.resetForm()
